@@ -17,6 +17,8 @@
 #' [`plot()`-method](https://easystats.github.io/see/articles/performance.html)
 #'  implemented in the [**see**-package](https://easystats.github.io/see/).
 #'
+#' @seealso [`see::plot.see_check_normality()`] for options to customize the plot.
+#'
 #' @details `check_normality()` calls `stats::shapiro.test` and checks the
 #' standardized residuals (or studentized residuals for mixed models) for
 #' normal distribution. Note that this formal test almost always yields
@@ -27,7 +29,7 @@
 #' standardized deviance residuals is shown (in line with changes in
 #' `plot.lm()` for R 4.3+).
 #'
-#' @examplesIf require("see")
+#' @examplesIf insight::check_if_installed("see", minimum_version = "0.9.1", quietly = TRUE)
 #' m <<- lm(mpg ~ wt + cyl + gear + disp, data = mtcars)
 #' check_normality(m)
 #'
@@ -48,17 +50,16 @@ check_normality <- function(x, ...) {
 }
 
 
-
 # default -------------------------
 
 #' @export
 check_normality.default <- function(x, ...) {
-  # check for valid input
   .is_model_valid(x)
 
   if (!insight::model_info(x)$is_linear) {
     insight::format_alert(
-      "Checking normality of residuals is only appropriate for linear models. It is recommended to use `simulate_residuals()` and `check_residuals()` to check generalized linear (mixed) models for uniformity of residuals." # nolint
+      "Checking normality of residuals is only appropriate for linear models.",
+      "Instead, please use `simulate_residuals()` and `check_residuals()` to test whether quantile residuals follow a uniform distribution." # nolint
     )
     return(NULL)
   }
@@ -86,8 +87,8 @@ check_normality.glm <- function(x, ...) {
   class(out) <- unique(c("check_normality", "see_check_normality", class(out)))
 
   insight::format_alert(
-    "There's no formal statistical test for normality for generalized linear model.",
-    "Instead, please use `simulate_residuals()` and `check_residuals()` to check for uniformity of residuals."
+    "Generalized linear model residuals are not expected to follow a normal distribution.",
+    "Instead, please use `simulate_residuals()` and `check_residuals()` to test whether quantile residuals follow a uniform distribution." # nolint
   )
   invisible(out)
 }
@@ -183,22 +184,22 @@ print.check_normality <- function(x, ...) {
 }
 
 
-
 # other classes --------------------
 
 # mixed models ---------------------
 
 #' @rdname check_normality
 #' @export
-check_normality.merMod <- function(x, effects = c("fixed", "random"), ...) {
+check_normality.merMod <- function(x, effects = "fixed", ...) {
   # args
-  effects <- match.arg(effects)
+  effects <- insight::validate_argument(effects, c("fixed", "random"))
   info <- insight::model_info(x)
 
   # valid model?
   if (!info$is_linear && effects == "fixed") {
     insight::format_alert(
-      "Checking normality of residuals is only appropriate for linear models. It is recommended to use `simulate_residuals()` and `check_residuals()` to check generalized linear (mixed) models for uniformity of residuals." # nolint
+      "Checking normality of residuals is only appropriate for linear models.",
+      "Instead, please use `simulate_residuals()` and `check_residuals()` to test whether quantile residuals follow a uniform distribution." # nolint
     )
     return(NULL)
   }
@@ -230,7 +231,7 @@ check_normality.merMod <- function(x, effects = c("fixed", "random"), ...) {
           p.val <- c(p.val, .check_normality(re[[i]][[j]], x, "random effects"))
         }
       }
-      attr(p.val, "re_qq") <- .diag_reqq(x, level = 0.95, model_info = info)
+      attr(p.val, "re_qq") <- .model_diagnostic_ranef_qq(x, level = 0.95, model_info = info)
       attr(p.val, "type") <- "random effects"
       attr(p.val, "re_groups") <- re_groups
     }
@@ -275,7 +276,6 @@ check_normality.afex_aov <- function(x, ...) {
 check_normality.BFBayesFactor <- check_normality.afex_aov
 
 
-
 # helper ---------------------
 
 .check_normality <- function(x, model, type = "residuals") {
