@@ -198,7 +198,8 @@
 #'  extreme values), this algorithm functions in a different manner and won't
 #'  always detect outliers. Note that `method = "optics"` requires the
 #'  **dbscan** package to be installed, and that it takes some time to compute
-#'  the results.
+#'  the results. Additionally, the `optics_xi` (default to 0.05) is passed to
+#'  the [dbscan::extractXi()] function to further refine the cluster selection.
 #'
 #'  - **Local Outlier Factor**:
 #'  Based on a K nearest neighbors algorithm, LOF compares the local density of
@@ -242,6 +243,7 @@
 #'   mcd = stats::qchisq(p = 1 - 0.001, df = ncol(x)),
 #'   ics = 0.001,
 #'   optics = 2 * ncol(x),
+#'   optics_xi = 0.05,
 #'   lof = 0.001
 #' )
 #' ```
@@ -301,17 +303,16 @@
 #' data <- mtcars # Size nrow(data) = 32
 #'
 #' # For single variables ------------------------------------------------------
-#' outliers_list <- check_outliers(data$mpg) # Find outliers
+#' # Find all observations beyond +/- 2 SD
+#' outliers_list <- check_outliers(data$mpg, method = "zscore", threshold = 2)
 #' outliers_list # Show the row index of the outliers
 #' as.numeric(outliers_list) # The object is a binary vector...
 #' filtered_data <- data[!outliers_list, ] # And can be used to filter a data frame
-#' nrow(filtered_data) # New size, 28 (4 outliers removed)
+#' nrow(filtered_data) # New size, 30 (2 outliers removed)
 #'
-#' # Find all observations beyond +/- 2 SD
-#' check_outliers(data$mpg, method = "zscore", threshold = 2)
 #'
 #' # For dataframes ------------------------------------------------------
-#' check_outliers(data) # It works the same way on data frames
+#' check_outliers(data, threshold = 2) # It works the same way on data frames
 #'
 #' # You can also use multiple methods at once
 #' outliers_list <- check_outliers(data, method = c(
@@ -333,7 +334,7 @@
 #' group_iris <- datawizard::data_group(iris, "Species")
 #' check_outliers(group_iris)
 #' # nolint start
-#' @examplesIf require("see") && require("bigutilsr") && require("loo") && require("MASS") && require("ICSOutlier") && require("ICS") && require("dbscan")
+#' @examplesIf all(insight::check_if_installed(c("bigutilsr", "MASS", "ICSOutlier", "ICS", "dbscan", "loo", "see"), quietly = TRUE))
 #' # nolint end
 #' \donttest{
 #' # You can also run all the methods
@@ -378,42 +379,23 @@ check_outliers.default <- function(x,
   # Check args
   if (all(method == "all")) {
     method <- c(
-      "zscore_robust",
-      "iqr",
-      "ci",
-      "cook",
-      "pareto",
-      "mahalanobis",
-      "mahalanobis_robust",
-      "mcd",
-      "ics",
-      "optics",
-      "lof"
+      "zscore_robust", "iqr", "ci", "cook", "pareto", "mahalanobis",
+      "mahalanobis_robust", "mcd", "ics", "optics", "lof"
     )
   }
 
   method <- match.arg(
     method,
     c(
-      "zscore",
-      "zscore_robust",
-      "iqr",
-      "ci",
-      "hdi",
-      "eti",
-      "bci",
-      "cook",
-      "pareto",
-      "mahalanobis",
-      "mahalanobis_robust",
-      "mcd",
-      "ics",
-      "optics",
-      "lof"
+      "zscore", "zscore_robust", "iqr", "ci", "hdi", "eti", "bci", "cook",
+      "pareto", "mahalanobis", "mahalanobis_robust", "mcd", "ics", "optics", "lof"
     ),
     several.ok = TRUE
   )
 
+  # Get model information
+  m_info <- insight::model_info(x)
+
   # Get data
   my_data <- insight::get_data(x, verbose = FALSE)
 
@@ -427,8 +409,17 @@ check_outliers.default <- function(x,
     )
   }
 
-  # Remove non-numerics
-  my_data <- datawizard::data_select(my_data, select = is.numeric, verbose = FALSE)
+  # Remove non-numerics, but in case of binomial, only check predictors
+  if (m_info$is_binomial) {
+    model_predictors <- unique(insight::find_predictors(x, flatten = TRUE))
+  } else {
+    model_predictors <- colnames(my_data)
+  }
+  my_data <- datawizard::data_select(
+    my_data[model_predictors],
+    select = is.numeric,
+    verbose = FALSE
+  )
 
   # check if any data left
   if (is.null(my_data) || ncol(my_data) == 0) {
@@ -468,7 +459,7 @@ check_outliers.default <- function(x,
   }
 
   # Cook
-  if ("cook" %in% method && !insight::model_info(x)$is_bayesian && !inherits(x, "bife")) {
+  if ("cook" %in% method && !m_info$is_bayesian && !inherits(x, "bife")) {
     data_cook <- .check_outliers_cook(
       x,
       threshold = thresholds$cook
@@ -508,7 +499,7 @@ check_outliers.default <- function(x,
   }
 
   # Pareto
-  if ("pareto" %in% method && insight::model_info(x)$is_bayesian) {
+  if ("pareto" %in% method && m_info$is_bayesian) {
     data_pareto <- .check_outliers_pareto(
       x,
       threshold = thresholds$pareto
@@ -588,7 +579,7 @@ check_outliers.default <- function(x,
   attr(outlier, "threshold") <- thresholds
   attr(outlier, "method") <- method
   attr(outlier, "text_size") <- 3
-  attr(outlier, "influential_obs") <- .influential_obs(x, threshold = unlist(thresholds))
+  attr(outlier, "influential_obs") <- .safe(.model_diagnostic_outlier(x, threshold = unlist(thresholds))) # nolint
   attr(outlier, "variables") <- "(Whole model)"
   attr(outlier, "raw_data") <- my_data
   attr(outlier, "outlier_var") <- outlier_var
@@ -598,7 +589,6 @@ check_outliers.default <- function(x,
 }
 
 
-
 # Methods -----------------------------------------------------------------
 
 #' @export
@@ -607,7 +597,7 @@ as.data.frame.check_outliers <- function(x, ...) {
 }
 
 #' @export
-as.numeric.check_outliers <- function(x, ...) {
+as.double.check_outliers <- function(x, ...) {
   attributes(x)$data$Outlier
 }
 
@@ -832,7 +822,6 @@ print.check_outliers_simres <- function(x, digits = 2, ...) {
 }
 
 
-
 # other classes -------------------------
 
 #' @rdname check_outliers
@@ -851,7 +840,6 @@ check_outliers.numeric <- function(x,
 }
 
 
-
 #' @rdname check_outliers
 #' @export
 check_outliers.data.frame <- function(x,
@@ -891,6 +879,13 @@ check_outliers.data.frame <- function(x,
   } else if (is.numeric(threshold)) {
     thresholds <- .check_outliers_thresholds(x)
     thresholds <- lapply(thresholds, function(x) threshold)
+    # need to fix this manually - "optics" automatically includes method
+    # "optics_xi", which is allowed to range between 0 and 1 - since values
+    # for "optics" can be > 1, it might overwrite "optics_xi" with an invalid
+    # value...
+    if (thresholds$optics_xi > 1) {
+      thresholds$optics_xi <- 0.05
+    }
   } else {
     insight::format_error(
       paste(
@@ -900,7 +895,13 @@ check_outliers.data.frame <- function(x,
     )
   }
 
-  thresholds <- thresholds[names(thresholds) %in% method]
+  # Keep only relevant threshold
+  valid <- method
+  if ("optics" %in% valid) {
+    valid <- c(valid, "optics_xi")
+    method <- c(method, "optics_xi")
+  }
+  thresholds <- thresholds[names(thresholds) %in% valid]
 
   out.meta <- .check_outliers.data.frame_method(x, method, thresholds, ID, ID.names, ...)
   out <- out.meta$out
@@ -1217,7 +1218,8 @@ check_outliers.data.frame <- function(x,
     out <- c(out, .check_outliers_optics(
       x,
       threshold = thresholds$optics,
-      ID.names = ID.names
+      ID.names = ID.names,
+      xi = thresholds$optics_xi
     ))
 
     count.table <- datawizard::data_filter(
@@ -1371,7 +1373,6 @@ check_outliers.BFBayesFactor <- function(x,
 }
 
 
-
 #' @export
 check_outliers.gls <- function(x,
                                method = "pareto",
@@ -1487,8 +1488,8 @@ check_outliers.metabin <- check_outliers.metagen
 #' @rdname check_outliers
 #' @export
 check_outliers.performance_simres <- function(x, type = "default", iterations = 100, alternative = "two.sided", ...) {
-  type <- match.arg(type, c("default", "binomial", "bootstrap"))
-  alternative <- match.arg(alternative, c("two.sided", "greater", "less"))
+  type <- insight::validate_argument(type, c("default", "binomial", "bootstrap"))
+  alternative <- insight::validate_argument(alternative, c("two.sided", "greater", "less"))
 
   insight::check_if_installed("DHARMa")
   result <- DHARMa::testOutliers(x, type = type, nBoot = iterations, alternative = alternative, plot = FALSE, ...)
@@ -1508,7 +1509,6 @@ check_outliers.performance_simres <- function(x, type = "default", iterations =
 check_outliers.DHARMa <- check_outliers.performance_simres
 
 
-
 # Thresholds --------------------------------------------------------------
 
 .check_outliers_thresholds <- function(x) {
@@ -1516,43 +1516,27 @@ check_outliers.DHARMa <- check_outliers.performance_simres
 }
 
 .check_outliers_thresholds_nowarn <- function(x) {
-  zscore <- stats::qnorm(p = 1 - 0.001 / 2)
-  zscore_robust <- stats::qnorm(p = 1 - 0.001 / 2)
-  iqr <- 1.7
-  ci <- 1 - 0.001
-  eti <- 1 - 0.001
-  hdi <- 1 - 0.001
-  bci <- 1 - 0.001
-  cook <- stats::qf(0.5, ncol(x), nrow(x) - ncol(x))
-  pareto <- 0.7
-  mahalanobis_value <- stats::qchisq(p = 1 - 0.001, df = ncol(x))
-  mahalanobis_robust <- stats::qchisq(p = 1 - 0.001, df = ncol(x))
-  mcd <- stats::qchisq(p = 1 - 0.001, df = ncol(x))
-  ics <- 0.001
-  optics <- 2 * ncol(x)
-  lof <- 0.001
-
   list(
-    zscore = zscore,
-    zscore_robust = zscore_robust,
-    iqr = iqr,
-    ci = ci,
-    hdi = hdi,
-    eti = eti,
-    bci = bci,
-    cook = cook,
-    pareto = pareto,
-    mahalanobis = mahalanobis_value,
-    mahalanobis_robust = mahalanobis_robust,
-    mcd = mcd,
-    ics = ics,
-    optics = optics,
-    lof = lof
+    zscore = stats::qnorm(p = 1 - 0.001 / 2),
+    zscore_robust = stats::qnorm(p = 1 - 0.001 / 2),
+    iqr = 1.7,
+    ci = 1 - 0.001,
+    hdi = 1 - 0.001,
+    eti = 1 - 0.001,
+    bci = 1 - 0.001,
+    cook = stats::qf(0.5, ncol(x), nrow(x) - ncol(x)),
+    pareto = 0.7,
+    mahalanobis = stats::qchisq(p = 1 - 0.001, df = ncol(x)),
+    mahalanobis_robust = stats::qchisq(p = 1 - 0.001, df = ncol(x)),
+    mcd = stats::qchisq(p = 1 - 0.001, df = ncol(x)),
+    ics = 0.001,
+    optics = 2 * ncol(x),
+    optics_xi = 0.05,
+    lof = 0.001
   )
 }
 
 
-
 # utilities --------------------
 
 .check_outliers_zscore <- function(x,
@@ -1611,7 +1595,6 @@ check_outliers.DHARMa <- check_outliers.performance_simres
 }
 
 
-
 .check_outliers_iqr <- function(x,
                                 threshold = 1.7,
                                 method = "tukey",
@@ -1663,7 +1646,6 @@ check_outliers.DHARMa <- check_outliers.performance_simres
 }
 
 
-
 .check_outliers_ci <- function(x,
                                threshold = 1 - 0.001,
                                method = "ci",
@@ -1714,7 +1696,6 @@ check_outliers.DHARMa <- check_outliers.performance_simres
 }
 
 
-
 .check_outliers_cook <- function(x,
                                  threshold = NULL,
                                  ID.names = NULL) {
@@ -1733,7 +1714,6 @@ check_outliers.DHARMa <- check_outliers.performance_simres
 }
 
 
-
 .check_outliers_pareto <- function(x, threshold = 0.7) {
   insight::check_if_installed("loo")
 
@@ -1753,7 +1733,6 @@ check_outliers.DHARMa <- check_outliers.performance_simres
 }
 
 
-
 .check_outliers_mahalanobis <- function(x,
                                         threshold = stats::qchisq(
                                           p = 1 - 0.001, df = ncol(x)
@@ -1783,7 +1762,6 @@ check_outliers.DHARMa <- check_outliers.performance_simres
 }
 
 
-
 # Bigutils not yet fully available on CRAN
 .check_outliers_mahalanobis_robust <- function(x,
                                                threshold = stats::qchisq(
@@ -1814,7 +1792,6 @@ check_outliers.DHARMa <- check_outliers.performance_simres
 }
 
 
-
 .check_outliers_mcd <- function(x,
                                 threshold = stats::qchisq(p = 1 - 0.001, df = ncol(x)),
                                 percentage_central = 0.75,
@@ -1858,7 +1835,6 @@ check_outliers.DHARMa <- check_outliers.performance_simres
 }
 
 
-
 .check_outliers_ics <- function(x,
                                 threshold = 0.001,
                                 ID.names = NULL,
@@ -1936,10 +1912,10 @@ check_outliers.DHARMa <- check_outliers.performance_simres
 }
 
 
-
 .check_outliers_optics <- function(x,
                                    threshold = NULL,
-                                   ID.names = NULL) {
+                                   ID.names = NULL,
+                                   xi = 0.05) {
   out <- data.frame(Row = seq_len(nrow(x)))
 
   if (!is.null(ID.names)) {
@@ -1950,7 +1926,7 @@ check_outliers.DHARMa <- check_outliers.performance_simres
 
   # Compute
   rez <- dbscan::optics(x, minPts = threshold)
-  rez <- dbscan::extractXi(rez, xi = 0.05) # TODO: find automatic way of setting xi
+  rez <- dbscan::extractXi(rez, xi = xi) # TODO: find automatic way of setting xi
 
   out$Distance_OPTICS <- rez$coredist
 
@@ -2001,7 +1977,6 @@ check_outliers.DHARMa <- check_outliers.performance_simres
 # }
 
 
-
 .check_outliers_lof <- function(x,
                                 threshold = 0.001,
                                 ID.names = NULL) {
@@ -2035,15 +2010,6 @@ check_outliers.DHARMa <- check_outliers.performance_simres
 }
 
 
-
-# influential observations data --------
-
-.influential_obs <- function(x, threshold = NULL) {
-  .safe(.diag_influential_obs(x, threshold = threshold))
-}
-
-
-
 # Non-supported model classes ---------------------------------------
 
 #' @export
