@@ -11,6 +11,9 @@
 #'   of frequentist models (e.g., `lm`, `merMod`, `glmmTMB`, ...). For Bayesian
 #'   models, the model is passed to [`bayesplot::pp_check()`].
 #'
+#'   If `check_predictions()` doesn't work as expected, try setting
+#'   `verbose = TRUE` to get hints about possible problems.
+#'
 #' @param object A statistical model.
 #' @param iterations The number of draws to simulate/bootstrap.
 #' @param check_range Logical, if `TRUE`, includes a plot with the minimum
@@ -37,7 +40,8 @@
 #'
 #' @return A data frame of simulated responses and the original response vector.
 #'
-#' @seealso [`simulate_residuals()`] and [`check_residuals()`].
+#' @seealso [`simulate_residuals()`] and [`check_residuals()`]. See also
+#' [`see::print.see_performance_pp_check()`] for options to customize the plot.
 #'
 #' @details An example how posterior predictive checks can also be used for model
 #'   comparison is Figure 6 from _Gabry et al. 2019, Figure 6_.
@@ -52,6 +56,9 @@
 #' package that imports **bayesplot** such as **rstanarm** or **brms**)
 #' is loaded, `pp_check()` is also available as an alias for `check_predictions()`.
 #'
+#' If `check_predictions()` doesn't work as expected, try setting `verbose = TRUE`
+#' to get hints about possible problems.
+#'
 #' @family functions to check model assumptions and and assess model quality
 #'
 #' @references
@@ -68,7 +75,7 @@
 #' - Gelman, A., Hill, J., and Vehtari, A. (2020). Regression and Other Stories.
 #'   Cambridge University Press.
 #'
-#' @examplesIf require("see")
+#' @examplesIf insight::check_if_installed("see", minimum_version = "0.9.1", quietly = TRUE)
 #' # linear model
 #' model <- lm(mpg ~ disp, data = mtcars)
 #' check_predictions(model)
@@ -99,8 +106,15 @@ check_predictions.default <- function(object,
                                       type = "density",
                                       verbose = TRUE,
                                       ...) {
-  # check for valid input
   .is_model_valid(object)
+  # check_predictions() can't handle exotic formula notation
+  if (verbose) {
+    insight::formula_ok(
+      object,
+      action = "error",
+      prefix_msg = "Posterior predictive checks failed due to an incompatible model formula." # nolint
+    )
+  }
 
   # retrieve model information
   minfo <- insight::model_info(object, verbose = FALSE)
@@ -112,29 +126,107 @@ check_predictions.default <- function(object,
   }
 
   # args
-  type <- match.arg(type, choices = c("density", "discrete_dots", "discrete_interval", "discrete_both"))
+  type <- insight::validate_argument(
+    type,
+    c("density", "discrete_dots", "discrete_interval", "discrete_both")
+  )
 
-  if (isTRUE(minfo$is_bayesian) && isFALSE(inherits(object, "BFBayesFactor"))) {
-    insight::check_if_installed(
-      "bayesplot",
-      "to create posterior prediction plots for Stan models"
-    )
-    bayesplot::pp_check(object)
+  pp_check.lm(
+    object,
+    iterations = iterations,
+    check_range = check_range,
+    re_formula = re_formula,
+    bandwidth = bandwidth,
+    type = type,
+    verbose = verbose,
+    model_info = minfo,
+    ...
+  )
+}
+
+
+#' @export
+check_predictions.stanreg <- function(object,
+                                      iterations = 50,
+                                      check_range = FALSE,
+                                      re_formula = NULL,
+                                      bandwidth = "nrd",
+                                      type = "density",
+                                      verbose = TRUE,
+                                      ...) {
+  # retrieve model information
+  minfo <- insight::model_info(object, verbose = FALSE)
+
+  # try to find sensible default for "type" argument
+  suggest_dots <- (minfo$is_bernoulli || minfo$is_count || minfo$is_ordinal || minfo$is_categorical || minfo$is_multinomial) # nolint
+  if (missing(type) && suggest_dots) {
+    type <- "discrete_interval"
+  }
+
+  # args
+  type <- insight::validate_argument(
+    type,
+    c("density", "discrete_dots", "discrete_interval", "discrete_both")
+  )
+
+  # convert to type-argument for pp_check
+  pp_type <- switch(type,
+    density = "dens",
+    "bars"
+  )
+
+  insight::check_if_installed(
+    "bayesplot",
+    "to create posterior prediction plots for Stan models"
+  )
+
+  # for plotting
+  resp_string <- insight::find_terms(object)$response
+
+  if (inherits(object, "brmsfit")) {
+    out <- as.data.frame(bayesplot::pp_check(object, type = pp_type, ndraws = iterations, ...)$data)
   } else {
-    pp_check.lm(
-      object,
-      iterations = iterations,
-      check_range = check_range,
-      re_formula = re_formula,
-      bandwidth = bandwidth,
-      type = type,
-      verbose = verbose,
-      model_info = minfo,
-      ...
+    out <- as.data.frame(bayesplot::pp_check(object, type = pp_type, nreps = iterations, ...)$data)
+  }
+
+  # bring data into shape, like we have for other models with `check_predictions()`
+  if (pp_type == "dens") {
+    d_filter <- out[!out$is_y, ]
+    d_filter <- datawizard::data_to_wide(
+      d_filter,
+      id_cols = "y_id",
+      values_from = "value",
+      names_from = "rep_id"
+    )
+    d_filter$y_id <- NULL
+    colnames(d_filter) <- paste0("sim_", colnames(d_filter))
+    d_filter$y <- out$value[out$is_y]
+    out <- d_filter
+  } else {
+    colnames(out) <- c("x", "y", "CI_low", "Mean", "CI_high")
+    # to long, for plotting
+    out <- datawizard::data_to_long(
+      out,
+      select = c("y", "Mean"),
+      names_to = "Group",
+      values_to = "Count"
     )
   }
+
+  attr(out, "is_stan") <- TRUE
+  attr(out, "check_range") <- check_range
+  attr(out, "response_name") <- resp_string
+  attr(out, "bandwidth") <- bandwidth
+  attr(out, "model_info") <- minfo
+  attr(out, "type") <- type
+  class(out) <- c("performance_pp_check", "see_performance_pp_check", class(out))
+  out
 }
 
+#' @export
+check_predictions.brmsfit <- check_predictions.stanreg
+
+
 #' @export
 check_predictions.BFBayesFactor <- function(object,
                                             iterations = 50,
@@ -150,7 +242,9 @@ check_predictions.BFBayesFactor <- function(object,
   if (isTRUE(is.na(re_formula))) {
     yy <- everything_we_need[["y_pred_marginal"]]
   } else {
-    if (!is.null(re_formula)) warning("re_formula can only be NULL or NA", call. = FALSE)
+    if (!is.null(re_formula)) {
+      insight::format_warning("`re_formula` can only be `NULL` or `NA`.")
+    }
     yy <- everything_we_need[["y_pred"]]
   }
 
@@ -175,7 +269,6 @@ check_predictions.lme <- function(object, ...) {
 }
 
 
-
 # pp-check functions -------------------------------------
 
 pp_check.lm <- function(object,
@@ -229,10 +322,18 @@ pp_check.lm <- function(object,
   pattern <- "^(scale|exp|expm1|log|log1p|log10|log2|sqrt)"
 
   # check for transformed response, and backtransform simulations
-  if (!is.null(resp_string) && grepl(paste0(pattern, "\\("), resp_string)) {
+  if (!is.null(resp_string) && length(resp_string) == 1 && grepl(paste0(pattern, "\\("), resp_string)) {
     out <- .backtransform_sims(out, resp_string)
   }
 
+  # sanity check - do we have a ratio or similar?
+  if (is.data.frame(response)) {
+    # get response data, evaluate formula
+    response <- eval(str2lang(insight::find_response(object)),
+      envir = insight::get_response(object)
+    )
+  }
+
   out$y <- response
 
   attr(out, "check_range") <- check_range
@@ -324,7 +425,6 @@ pp_check.glmmTMB   <-
 # styler: on
 
 
-
 #' @rawNamespace
 #' S3method(bayesplot::pp_check, lm)
 #' S3method(bayesplot::pp_check, glm)
@@ -341,20 +441,6 @@ pp_check.glmmTMB   <-
 #' S3method(bayesplot::pp_check, BFBayesFactor)
 
 
-
-# aliases --------------------------
-
-#' @rdname check_predictions
-#' @export
-posterior_predictive_check <- check_predictions
-
-#' @rdname check_predictions
-#' @export
-check_posterior_predictions <- check_predictions
-
-
-
-
 # methods -----------------------
 
 
@@ -430,7 +516,7 @@ plot.performance_pp_check <- function(x, ...) {
     if (is.null(plus_minus)) {
       plus_minus <- .safe(eval(parse(text = gsub("log\\(([^,\\+)]*)(.*)\\)", "\\1", resp_string))))
     }
-    if (is.null(plus_minus)) {
+    if (is.null(plus_minus) || !is.numeric(plus_minus)) {
       sims[] <- lapply(sims, exp)
     } else {
       sims[] <- lapply(sims, function(i) exp(i) - plus_minus)
@@ -457,7 +543,7 @@ plot.performance_pp_check <- function(x, ...) {
   # validation check, for mixed models, where re.form = NULL (default) might fail
   if (is.null(out) && insight::is_mixed_model(object) && !isTRUE(is.na(re_formula))) {
     if (verbose) {
-      insight::format_warning(
+      insight::format_alert(
         paste0(
           "Failed to compute posterior predictive checks with `re_formula=",
           deparse(re_formula),
