@@ -59,7 +59,10 @@ performance_pcp <- function(model,
     model <- model$fit
   }
 
-  method <- match.arg(method, choices = c("Herron", "Gelman-Hill", "herron", "gelman_hill"))
+  method <- insight::validate_argument(
+    method,
+    c("Herron", "Gelman-Hill", "herron", "gelman_hill")
+  )
   mi <- insight::model_info(model, verbose = verbose)
 
   if (!mi$is_binomial) {
@@ -84,7 +87,6 @@ performance_pcp <- function(model,
 }
 
 
-
 # methods ----------------------------------
 
 #' @export
@@ -126,7 +128,6 @@ as.data.frame.performance_pcp <- function(x, row.names = NULL, ...) {
 }
 
 
-
 # utilities --------------------------------------
 
 .performance_pcp <- function(model, m0, ci, method, verbose = TRUE) {
